@@ -12,28 +12,36 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Write and run Hadoop Streaming jobs on Amazon Elastic MapReduce or your own Hadoop cluster.
+"""Write and run Hadoop Streaming jobs on Amazon Elastic MapReduce or your own
+Hadoop cluster.
 """
 
 __author__ = 'David Marin <dave@yelp.com>'
 
 __credits__ = [
     'Jordan Andersen <jordandandersen@gmail.com>',
+    'Hunter Blanks <hblanks@monetate.com>',
     'Jim Blomo <jblomo@yelp.com>',
     'James Brown <jbrown@yelp.com>',
+    'Kevin Burke <kevin@twilio.com>',
+    'David Dehghan <ddehghan@gmail.com>',
     'Adam Derewecki <derewecki@gmail.com>',
+    'Benjamin Goldenberg <benjamin@yelp.com',
     'Peter Harrington <peter.b.harrington@gmail.com>',
+    'Brandon Haynes <bhaynes@fas.harvard.edu>',
     'Brett Hoerner <brett@bretthoerner.com>',
     'Stephen Johnson <sjohnson@yelp.com>',
     'Matt Jones <mattj@yelp.com>',
+    'Nikolaos Koutsopoulos <nhk@mochimedia.com>',
     'Julian Krause <juliank@yelp.com>',
     'Robert Leftwich <rl.0x0@eml.cc>',
     'Wahbeh Qardaji <wqardaji@yelp.com>',
     'Jimmy Retzlaff <jretz@yelp.com>',
     'Ned Rockson <ned@tellapart.com>',
     'Steve Spencer <steve@bigfrog.net>',
+    'Jyry Suvilehto <jyry.suvilehto@iki.fi>',
     'Matthew Tai <mtai@adku.com>',
     'Paul Wais <pwais@yelp.com>',
 ]
 
-__version__ = '0.2.7'
+__version__ = '0.3.2'
